Update ethaddr handling on CMC-PU2 board
Patch by Martin Krause, 16 Nov 2005

If the environment variable 'ethaddr' is not set in flash it is read from
EEPROM (if valid), set in RAM and now also saved to flash. The same applies
for the variable 'serial#'.
This is done to optimise series production. Now, no 'saveenv' command
has to be applied over the serial line. And thus no serial connection
is necessery at all. Setting ethaddr only in RAM is not sufficient,
because 'ethaddr' and 'serial#'  must be readable from linux with the 
fw_printenv tool.

---
commit d69cafcdc3ab5ce15975f0202c52e122fc3f9076
tree fa66b3442edb055a2c0f25aaa1ed91b34bf32cea
parent fad8b62488b10f8d4017f6daf1379eb641dcee89
author Martin Krause <mkr@tq-sewsrv-4.tq-net.de> Wed, 16 Nov 2005 11:51:44 +0100
committer Martin Krause <mkr@tq-sewsrv-4.tq-net.de> Wed, 16 Nov 2005 11:51:44 +0100

 board/cmc_pu2/load_sernum_ethaddr.c |   15 ++++++++++++++-
 include/configs/cmc_pu2.h           |    6 ++++++
 2 files changed, 20 insertions(+), 1 deletions(-)

diff --git a/board/cmc_pu2/load_sernum_ethaddr.c b/board/cmc_pu2/load_sernum_ethaddr.c
index 94aa30d..5ff7a03 100644
--- a/board/cmc_pu2/load_sernum_ethaddr.c
+++ b/board/cmc_pu2/load_sernum_ethaddr.c
@@ -74,6 +74,9 @@ void load_sernum_ethaddr (void)
 	unsigned short chksum;
 	unsigned char *p;
 	unsigned short i, is, id;
+#if defined CONFIG_CMC_AUTO_SAVEENV
+	unsigned int needs_save = 0;
+#endif
 
 #if !defined(CONFIG_HARD_I2C) && !defined(CONFIG_SOFT_I2C)
 #error you must define some I2C support (CONFIG_HARD_I2C or CONFIG_SOFT_I2C)
@@ -114,9 +117,19 @@ void load_sernum_ethaddr (void)
 	/* set serial# and ethaddr if not yet defined */
 	if (getenv("serial#") == NULL) {
 		setenv ("serial#", serial);
+#if defined CONFIG_CMC_AUTO_SAVEENV
+		needs_save = 1;
+#endif
 	}
-
 	if (getenv("ethaddr") == NULL) {
 		setenv ("ethaddr", ethaddr);
+#if defined CONFIG_CMC_AUTO_SAVEENV
+		needs_save = 1;
+#endif
+	}
+#if defined CONFIG_CMC_AUTO_SAVEENV
+	if (needs_save) {
+		saveenv ();
 	}
+#endif
 }
diff --git a/include/configs/cmc_pu2.h b/include/configs/cmc_pu2.h
index bcbad30..10beffa 100644
--- a/include/configs/cmc_pu2.h
+++ b/include/configs/cmc_pu2.h
@@ -147,6 +147,12 @@
 #define CONFIG_DRIVER_ETHER
 #define CONFIG_NET_RETRY_COUNT		20
 #define CONFIG_AT91C_USE_RMII
+/* 
+ * Define CONFIG_CMC_AUTO_SAVEENV if you want to automatically save the
+ * ethaddr and serial# read from EEPROM permanently in flash (in contrast to
+ * only set it in the RAM environment)
+ */
+#define CONFIG_CMC_AUTO_SAVEENV
 
 #define CFG_SPI_WRITE_TOUT		(5*CFG_HZ)
 #define CFG_MAX_DATAFLASH_BANKS		2
